@@ -3,13 +3,14 @@ BEGIN {
   $App::OS::Detect::MachineCores::AUTHORITY = 'cpan:DBR';
 }
 {
-  $App::OS::Detect::MachineCores::VERSION = '0.038';
+  $App::OS::Detect::MachineCores::VERSION = '1.0.0';
 }
 
 #  PODNAME: App::OS::Detect::MachineCores
 # ABSTRACT: Detect how many cores your machine has (OS-independently)
 
 use true;
+use Carp;
 use 5.010;
 use strict;
 use warnings;
@@ -25,26 +26,23 @@ has os => (
 
 has cores => (
     is      => 'rw',
-    isa     => sub { die "$_[0] is not a number!" unless $_[0] ~~ [0..100] },
+    isa     => sub { die "$_[0] is not a reasonable number of cores!" unless $_[0] > 0 and $_[0] < 100 },
     lazy    => 1,
     builder => '_build_cores',
 );
 
 option add_one => (
     is      => 'rw',
-    isa     => sub { die "Invalid bool!" unless $_[0] ~~ [ 0 .. 1 ] },
+    isa     => sub { die "Invalid bool!" unless $_[0] == 0 or $_[0] == 1 },
     default => sub { '0' },
     short   => 'i',
     doc     => q{add one to the number of cores (useful in scripts)},
 );
 
 sub _build_cores {
-    do { 
-        given ($_[0]->os) {
-            when ('darwin') { $_ = `sysctl hw.ncpu | awk '{print \$2}'`;     chomp; $_ }
-            when ('linux')  { $_ = `grep processor < /proc/cpuinfo | wc -l`; chomp; $_ }
-        }
-    } or '0'
+    if    ($_[0]->os =~ 'darwin') { $_ = `sysctl hw.ncpu | awk '{print \$2}'`;     chomp; $_ }
+    elsif ($_[0]->os =~ 'linux')  { $_ = `grep processor < /proc/cpuinfo | wc -l`; chomp; $_ }
+    else { carp "Can't detect the cores for your system/OS, sorry." }
 }
 
 around cores => sub {
@@ -56,9 +54,8 @@ around cores => sub {
 
 no Moo;
 
-
-
 __END__
+
 =pod
 
 =encoding utf-8
@@ -69,7 +66,7 @@ App::OS::Detect::MachineCores - Detect how many cores your machine has (OS-indep
 
 =head1 VERSION
 
-version 0.038
+version 1.0.0
 
 =head1 SYNOPSIS
 
@@ -126,4 +123,3 @@ This is free software, licensed under:
   DO WHAT THE FUCK YOU WANT TO PUBLIC LICENSE, Version 2, December 2004
 
 =cut
-
